@@ -25,7 +25,8 @@ import static org.fusesource.hawtjni.runtime.FieldFlag.*;
 import static org.fusesource.hawtjni.runtime.MethodFlag.*;
 
 /**
- * 
+ * Interface to access Win32 base APIs.
+ *
  * @author <a href="http://hiramchirino.com">Hiram Chirino</a>
  */
 @JniClass(conditional="defined(_WIN32) || defined(_WIN64)")
@@ -306,8 +307,14 @@ public class Kernel32 {
             return window.height() + 1;
         }
     }
-    
-    
+
+
+    // DWORD WINAPI WaitForSingleObject(
+    //  _In_ HANDLE hHandle,
+    //  _In_ DWORD  dwMilliseconds
+    // );
+    public static final native int WaitForSingleObject(@JniArg(cast="HANDLE")long hHandle, int dwMilliseconds);
+
     /**
      * see: http://msdn.microsoft.com/en-us/library/ms724211%28VS.85%29.aspx
      * 
@@ -452,12 +459,12 @@ public class Kernel32 {
     public static final native int _getch();
     
 
-   /**
-    * see: http://msdn.microsoft.com/en-us/library/ms686050%28VS.85%29.aspx
-    * @param title
-    * @return 0 if title was set successfully
-    */
-   public static final native int SetConsoleTitle(
+    /**
+     * see: http://msdn.microsoft.com/en-us/library/ms686050%28VS.85%29.aspx
+     * @param title
+     * @return 0 if title was set successfully
+     */
+    public static final native int SetConsoleTitle(
                @JniArg(flags={UNICODE}) String title);    
 
 
@@ -568,7 +575,6 @@ public class Kernel32 {
     /**
      * see: http://msdn.microsoft.com/en-us/library/ms684239(v=VS.85).aspx
      */
-    /*
     @JniClass(flags={ClassFlag.STRUCT,TYPEDEF}, conditional="defined(_WIN32) || defined(_WIN64)")
     public static class MOUSE_EVENT_RECORD {
 
@@ -638,12 +644,10 @@ public class Kernel32 {
                     '}';
         }
     }
-    */
 
     /**
      * see: http://msdn.microsoft.com/en-us/library/ms687093(v=VS.85).aspx
      */
-    /*
     @JniClass(flags={ClassFlag.STRUCT,TYPEDEF}, conditional="defined(_WIN32) || defined(_WIN64)")
     public static class WINDOW_BUFFER_SIZE_RECORD {
 
@@ -664,12 +668,10 @@ public class Kernel32 {
             return "WINDOW_BUFFER_SIZE_RECORD{size=" + size + '}';
         }
     }
-    */
 
     /**
      * see: http://msdn.microsoft.com/en-us/library/ms683149(v=VS.85).aspx
      */
-    /*
     @JniClass(flags={ClassFlag.STRUCT,TYPEDEF}, conditional="defined(_WIN32) || defined(_WIN64)")
     public static class FOCUS_EVENT_RECORD {
         static {
@@ -683,12 +685,10 @@ public class Kernel32 {
         @JniField(accessor="bSetFocus")
         public boolean setFocus;
     }
-    */
 
     /**
      * see: http://msdn.microsoft.com/en-us/library/ms684213(v=VS.85).aspx
      */
-    /*
     @JniClass(flags={ClassFlag.STRUCT,TYPEDEF}, conditional="defined(_WIN32) || defined(_WIN64)")
     public static class MENU_EVENT_RECORD {
         static {
@@ -702,7 +702,6 @@ public class Kernel32 {
         @JniField(accessor="dwCommandId")
         public int commandId;
     }
-    */
 
     /**
      * see: http://msdn.microsoft.com/en-us/library/ms683499(v=VS.85).aspx
@@ -721,7 +720,6 @@ public class Kernel32 {
         public static int SIZEOF;
         @JniField(flags={CONSTANT}, accessor="KEY_EVENT")
         public static short KEY_EVENT;
-        /*
         @JniField(flags={CONSTANT}, accessor="MOUSE_EVENT")
         public static short MOUSE_EVENT;
         @JniField(flags={CONSTANT}, accessor="WINDOW_BUFFER_SIZE_EVENT")
@@ -730,12 +728,10 @@ public class Kernel32 {
         public static short FOCUS_EVENT;
         @JniField(flags={CONSTANT}, accessor="MENU_EVENT")
         public static short MENU_EVENT;
-        */
         @JniField(accessor="EventType")
         public short eventType;
         @JniField(accessor="Event.KeyEvent")
         public KEY_EVENT_RECORD keyEvent = new KEY_EVENT_RECORD();
-        /*
         @JniField(accessor="Event.MouseEvent")
         public MOUSE_EVENT_RECORD mouseEvent = new MOUSE_EVENT_RECORD();
         @JniField(accessor="Event.WindowBufferSizeEvent")
@@ -744,7 +740,7 @@ public class Kernel32 {
         public MENU_EVENT_RECORD menuEvent = new MENU_EVENT_RECORD();
         @JniField(accessor="Event.FocusEvent")
         public FOCUS_EVENT_RECORD focusEvent = new FOCUS_EVENT_RECORD();
-        */
+
         public static final native void memmove (
           @JniArg(cast="void *", flags={NO_IN, CRITICAL}) INPUT_RECORD dest,
           @JniArg(cast="const void *", flags={NO_OUT, CRITICAL}) long src,
